<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>No hay notificaciones recientes</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Centro de notificaciones</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpiar todo</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desfijar</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fijar</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ajustes de notificaciones</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Ahora mismo</translation>
    </message>
</context>
</TS>
